aboutsummaryrefslogtreecommitdiffstats
path: root/native-tools/bsincgen.c
diff options
context:
space:
mode:
Diffstat (limited to 'native-tools/bsincgen.c')
-rw-r--r--native-tools/bsincgen.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/native-tools/bsincgen.c b/native-tools/bsincgen.c
index 49102279..72bd8183 100644
--- a/native-tools/bsincgen.c
+++ b/native-tools/bsincgen.c
@@ -356,8 +356,8 @@ int main(int argc, char *argv[])
"} BSincTable;\n\n", BSINC_SCALE_COUNT, BSINC_PHASE_COUNT, FRACTIONONE);
/* A 23rd order filter with a -60dB drop at nyquist. */
BsiGenerateTables(output, "bsinc24", 60.0, 23);
- /* An 11th order filter with a -60dB drop at nyquist. */
- BsiGenerateTables(output, "bsinc12", 60.0, 11);
+ /* An 11th order filter with a -40dB drop at nyquist. */
+ BsiGenerateTables(output, "bsinc12", 40.0, 11);
if(output != stdout)
fclose(output);